<img align="right" src="https://raw.githubusercontent.com/radish-bdd/radish/master/artwork/radish-bdd-logo-trans-bg.png">
# radish - the root from red to green
> Awesome python BDD tool http://radish-bdd.io

***

[![PyPI License](https://img.shields.io/pypi/l/radish-bdd.svg)](https://github.com/radish-bdd/radish/blob/master/LICENSE)
[![Build Status](https://travis-ci.org/radish-bdd/radish.svg?branch=master)](https://travis-ci.org/radish-bdd/radish)
<br>
[![PyPI version](https://badge.fury.io/py/radish-bdd.svg)](https://badge.fury.io/py/radish-bdd)
[![PyPI](https://img.shields.io/pypi/pyversions/radish-bdd.svg)](https://pypi.python.org/pypi/radish-bdd)
[![PyPI](https://img.shields.io/pypi/wheel/radish-bdd.svg)](https://pypi.python.org/pypi/radish-bdd)
<br>
[![codecov.io](https://codecov.io/github/radish-bdd/radish/coverage.svg?branch=master)](https://codecov.io/github/radish-bdd/radish?branch=master)
[![Code Health](https://landscape.io/github/radish-bdd/radish/master/landscape.svg?style=flat)](https://landscape.io/github/radish-bdd/radish/master)
[![Code Issues](https://www.quantifiedcode.com/api/v1/project/27441974a1a343d5813ad90cf0db3c07/badge.svg)](https://www.quantifiedcode.com/app/project/27441974a1a343d5813ad90cf0db3c07)


***

# What is radish?

radish is a Behavior Driven Development tool completely written in python. It supports all *gherkin* language features. In addition to that, radish implements a few *unconventional* BDD features such as **Preconditions**, **Scenario Loops**, **Constants** and **Expressions**.

# Installation

radish is available as `pip` package:

```bash
pip install radish-bdd
```

**Note**: Make sure you have enough privileges to install radish on your system.

# Getting started

radish is very easy to use. Take the 5 minutes and follow the *Getting started* instruction on the radish website: http://radish-bdd.io/#gettingstarted

# Documentation

The whole documentation of radish is available on [Read The Docs](http://radish.readthedocs.org).

# Contribution

Yes, we are looking for some contributors and people who spread out a word about radish. Help us to improve these piece of software. You don't know what to do?
Just have a look at the Issues or create a new one.
Please have a look at the [Contributing Guidelines](https://github.com/radish-bdd/radish/blob/master/CONTRIBUTING.md), too.

# Special Thanks

A special thanks goes to [Hassan Ashraf](mailto:info@cyberavanza.com) from the company [Cyber Avanza](http://www.cyberavanza.com) for creating an awesome logo for free! I really appreciate their work and time!
